Identifier
==========

.. currentmodule:: fastobo.id
.. automodule:: fastobo.id

.. autoclass:: BaseIdent
   :members:
   :special-members:


.. autoclass:: PrefixedIdent(BaseIdent)
   :members:
   :special-members:


.. autoclass:: UnprefixedIdent(BaseIdent)
   :members:
   :special-members:


.. autoclass:: Url(BaseIdent)
   :members:
   :special-members:
